#include "x2goplasmoid.h"
#include <QPainter>
#include <QFontMetrics>
#include <QSizeF>
#include <KLocale>

#include <plasma/svg.h>
#include <plasma/theme.h>

#include <plasma/widgets/label.h>
#include <plasma/widgets/pushbutton.h>
#include <plasma/widgets/frame.h>
#include <plasma/widgets/flashinglabel.h>
#include <plasma/widgets/scrollwidget.h>

#include <plasma/tooltipmanager.h>

#include <KPushButton>
#include <KUser>

#include <QGraphicsLinearLayout>

#include <QDebug>
#include <QTimer>
#include <QFile>

#include "plasmax2godialog.h"

static const char *DEFAULT_ICON_NAME = "x2go";

// This is the command that links your applet to the .desktop file
K_EXPORT_PLASMA_APPLET(x2goplasmoid, x2goplasmoid)


x2goplasmoid::x2goplasmoid ( QObject *parent, const QVariantList &args )
        : Plasma::PopupApplet ( parent, args ),
        m_dialog(0)
{
	setAspectRatioMode(Plasma::IgnoreAspectRatio);
	resize(graphicsWidget()->minimumSize());
	setPopupIcon(DEFAULT_ICON_NAME);

	sessionId=getenv("X2GO_SESSION");
	if(sessionId.length()<=0)
	{
		// setEnabled(false);
		// m_dialog->dialog()->setEnabled(false);
		return;
	}

	setBackgroundHints ( DefaultBackground );
	setHasConfigurationInterface ( true );

	//init widget
	setMinimumSize(22,22);

	KUser user;
	stampFName="/tmp/.x2go-"+user.loginName()+"/"+sessionId+".plasmoid";
	slotUpdateStamp();
	QTimer *timer = new QTimer(this);
	connect(timer, SIGNAL(timeout()), this, SLOT(slotUpdateStamp()));
	timer->start(5000);
}


x2goplasmoid::~x2goplasmoid()
{
	if ( hasFailedToLaunch() )
	{
	}
	else
	{
	}
	QFile::remove(stampFName);
	delete m_dialog;
}


void x2goplasmoid::init()
{
	Plasma::ToolTipManager::self()->registerWidget(this);
	Plasma::ToolTipContent toolTip;
	toolTip.setMainText(i18n("X2Go Plasmoid"));
	toolTip.setSubText(i18n("Manage X2Go shares\nSuspend session"));
	toolTip.setImage(KIcon(DEFAULT_ICON_NAME));
	Plasma::ToolTipManager::self()->setContent(this,toolTip);
}

QGraphicsWidget* x2goplasmoid::graphicsWidget()
{
	if (!m_dialog)
		m_dialog=new PlasmaX2goDialog(this);
	return m_dialog->dialog();
}


void x2goplasmoid::slotUpdateStamp()
{
	QFile file(stampFName);
	if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
		return;

	QTextStream out(&file);
	out << QDateTime::currentDateTime().toTime_t();
}


#include "x2goplasmoid.moc"
